pywr.recorders.Recorder — Pywr 0.5dev documentation

# pywr.recorders.Recorder

class `pywr.recorders.` `Recorder`

  Base class for recording information from a pywr.model.Model.

  Recorder components are used to calculate, aggregate and save data from a simulation. This base class provides the basic functionality for all recorders.

  Parameters: | model : pywr.core.Model agg_func : str or callable (default=”mean”) Scenario aggregation function to use when aggregated_value is called. name : str (default=None) Name of the recorder. comment : str (default=None) Comment or description of the recorder. ignore_nan : bool (default=False) Flag to ignore NaN values when calling aggregated_value. is_objective : {None, ‘maximize’, ‘maximise’, ‘max’, ‘minimize’, ‘minimise’, ‘min’} Flag to denote the direction, if any, of optimisation undertaken with this recorder. is_constraint : bool (default=False) Flag to denote whether this recorder is to be used as a constraint during optimisation. epsilon : float (default=1.0) Epsilon distance used by some optimisation algorithms.

  `__init__`($self, /, *args, **kwargs)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `after` |
  `aggregated_value` |
  `before` |
  `finish` |
  `load` |
  `register` |
  `reset` |
  `setup` |
  `unregister` |
  `values` |

  Attributes

  `agg_func` |
  `children` |
  `comment` |
  `epsilon` |
  `ignore_nan` |
  `is_constraint` |
  `is_objective` |
  `model` |
  `name` |
  `parents` |